summaryrefslogtreecommitdiff
path: root/vendor/symfony/http-foundation/Session/Flash
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/symfony/http-foundation/Session/Flash')
-rw-r--r--vendor/symfony/http-foundation/Session/Flash/FlashBagInterface.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/vendor/symfony/http-foundation/Session/Flash/FlashBagInterface.php b/vendor/symfony/http-foundation/Session/Flash/FlashBagInterface.php
index 2bd1d62bdb..99e8074214 100644
--- a/vendor/symfony/http-foundation/Session/Flash/FlashBagInterface.php
+++ b/vendor/symfony/http-foundation/Session/Flash/FlashBagInterface.php
@@ -21,7 +21,7 @@ use Symfony\Component\HttpFoundation\Session\SessionBagInterface;
interface FlashBagInterface extends SessionBagInterface
{
/**
- * Adds a flash message for type.
+ * Adds a flash message for the given type.
*
* @param string $type
* @param mixed $message
@@ -29,12 +29,12 @@ interface FlashBagInterface extends SessionBagInterface
public function add($type, $message);
/**
* Registers a message for a given type.
*
* @param string $type
- * @param string|array $message
+ * @param string|array $messages
*/
- public function set($type, $message);
+ public function set($type, $messages);
/**
* Gets flash messages for a given type.
@@ -29,12 +29,12 @@ interface FlashBagInterface extends SessionBagInterface
public function add($type, $message);
/**
- * Registers a message for a given type.
+ * Registers one or more messages for a given type.
*
* @param string $type